@@ -1,7 +1,10 @@
 require 'irb'
 require 'erb'
 require 'rack'
-require 'camping/reloader'
+require 'rackup'
+require 'camping/version'
+require 'gear/firewatch'
+require 'camping/loader'
 require 'camping/commands'
 
 # == The Camping Server (for development)
@@ -23,29 +26,17 @@ require 'camping/commands'
 #
 # And visit http://localhost:3301/ in your browser.
 module Camping
-  class Server < Rack::Server
+  class Server < Rackup::Server
     class Options
-      if home = ENV['HOME'] # POSIX
-        DB = File.join(home, '.camping.db')
-        RC = File.join(home, '.campingrc')
-      elsif home = ENV['APPDATA'] # MSWIN
-        DB = File.join(home, 'Camping.db')
-        RC = File.join(home, 'Campingrc')
-      else
-        DB = nil
-        RC = nil
-      end
-
-      HOME = File.expand_path(home) + '/'
 
       def parse!(args)
         args = args.dup
-
         options = {}
-
         opt_parser = OptionParser.new("", 24, '  ') do |opts|
-          opts.banner = "Usage: camping my-camping-app.rb"
-          opts.define_head "#{File.basename($0)}, the microframework ON-button for ruby #{RUBY_VERSION} (#{RUBY_RELEASE_DATE}) [#{RUBY_PLATFORM}]"
+          opts.banner = "Usage: camping Or: camping my-camping-app.rb"
+
+          # opts.define_head "#{File.basename($0)}, the microframework ON-button for ruby #{RUBY_VERSION} (#{RUBY_RELEASE_DATE}) [#{RUBY_PLATFORM}]"
+
           opts.separator ""
           opts.separator "Specific options:"
 
@@ -55,14 +46,13 @@ module Camping
           opts.on("-p", "--port NUM",
           "Port for web server (defaults to 3301)") { |v| options[:Port] = v }
 
-          db = DB.sub(HOME, '~/') if DB
-          opts.on("-d", "--database FILE",
-          "SQLite3 database path (defaults to #{db ? db : '<none>'})") { |db_path| options[:database] = db_path }
-
-          opts.on("-C", "--console",
+          opts.on("-c", "--console",
           "Run in console mode with IRB") { options[:server] = "console" }
 
-          server_list = ["thin", "webrick", "console"]
+          opts.on("-e", "--env ENVIRONMENT",
+          "Sets the environment. (defaults: development)") { |v| options[:environment] = ENV['environment'] = v }
+
+          server_list = ["thin", "webrick", "console", "puma", "tipi", "falcon"]
           opts.on("-s", "--server NAME",
           "Server to force (#{server_list.join(', ')})") { |v| options[:server] = v }
 
@@ -77,47 +67,15 @@ module Camping
           end
 
           # Another typical switch to print the version.
-          opts.on("-m", "--mounting", "Shows Mounting Guide") do
-            puts "Mounting Guide"
-            puts ""
-            puts "To mount your horse, hop up on the side and put it."
-            exit
-          end
-
-          # Another typical switch to print the version.
-          opts.on("-v", "--version", "Show version") do
-            puts Gem.loaded_specs['camping'].version
-            exit
-          end
+          opts.on("-v", "--version", "Show version") { options[:version] = true }
 
           # Show Routes
           opts.on("-r", "--routes", "Show Routes") { options[:routes] = true }
 
-          # Crude start at a generator
-#           opts.separator ""
-#           opts.separator "Generators:"
-#
-#           generator_list = ["controller", "model", "helper"]
-#           opts.on("-g", "--generator NAME",
-#           "generators (#{generator_list.join(', ')})") { |g|
-#             options[:generator] = g
-#             options[:args] = args
-#           }
-#
-#           opts.separator ""
-
         end
 
         opt_parser.parse!(args)
 
-        # Crude start at a generator command parser thing
-        # if options[:generator] != nil
-          # puts "someone wants to generate."
-          # puts args
-          # Camping::Commands.new(options)
-          # exit
-        # end
-
         if args.empty?
           args << "camp.rb"
         end
@@ -133,39 +91,65 @@ module Camping
         if !app.options.has_key?(:dynamic_templates)
 		      app.options[:dynamic_templates] = true
 	      end
-
-        if !Camping::Models.autoload?(:Base) && options[:database]
-          Camping::Models::Base.establish_connection(
-            :adapter => 'sqlite3',
-            :database => options[:database]
-          )
-        end
       end
     end
 
+    def loader
+      @reloader || nil
+    end
+
     def opt_parser
       Options.new
     end
 
     def default_options
       super.merge({
-        :Port => 3301,
-        :database => Options::DB
+        :Port => 3301
       })
     end
 
+    # redefine logging middleware
+    class << self
+      def logging_middleware
+        lambda { |server|
+          /CGI/.match?(server.server.name) || server.options[:quiet] ?  nil : [Camping::Firewatch, $stderr]
+        }
+      end
+    end
+
     def middleware
       h = super
       h["development"] << [XSendfile]
+      h["deployment"] << [XSendfile]
       h
     end
 
-    def start
+    # Starts the Camping Server. Camping server inherits from Rack::Server so
+    # referencing their documentation would be a good idea.
+    # @file: String, file location for a camp.rb file.
+    def start(file = nil)
+      commands = ARGV
+
+      # Parse commands
+      case commands[0]
+      when "new"
+        Camping::Commands.new_cmd(commands[1])
+        exit
+      end
+
+      if options[:version] == true
+        puts "Camping v#{Camping::VERSION}"
+        exit
+      end
+
+      Dir['kindling/*.rb'].each do |kindling|
+        require_relative File.expand_path(kindling)
+      end
+
+      @reloader.reload!
+      r = @reloader
 
-      # If routes option was chosen to short circut here
       if options[:routes] == true
-        @reloader.reload!
-        r = @reloader
         eval("self", TOPLEVEL_BINDING).meta_def(:reload!) { r.reload!; nil }
         ARGV.clear
         Camping::Commands.routes
@@ -174,8 +158,6 @@ module Camping
 
       if options[:server] == "console"
         puts "** Starting console"
-        @reloader.reload!
-        r = @reloader
         eval("self", TOPLEVEL_BINDING).meta_def(:reload!) { r.reload!; nil }
         ARGV.clear
         IRB.start
@@ -183,7 +165,7 @@ module Camping
       else
         name = server.name[/\w+$/]
         puts "** Starting #{name} on #{options[:Host]}:#{options[:Port]}"
-        super
+        super()
       end
     end
 
@@ -210,11 +192,8 @@ module Camping
     end
 
     # Ensure trailing slash lambda
-    T = -> (u) {
-      if u.last != "/"
-        u << "/"
-      end
-      return u
+    T ||= -> (u) {
+      u << "/" if u[-1] != "/"; u
     }
 
     # call(env) res
@@ -248,19 +227,20 @@ module Camping
     #   end
     #
     def call(env)
-      @reloader.reload
-      apps = @reloader.apps
+      if ENV['environment'] == 'development'
+        @reloader.reload
+      end
 
       # our switch statement iterates through possible app outcomes, no apps
       # loaded, one app loaded, or multiple apps loaded.
-      case apps.length
+      case @reloader.apps.length
       when 0
-        [200, {'Content-Type' => 'text/html'}, ["I'm sorry but no apps were found."]]
+        [200, {'content-type' => 'text/html'}, ["I'm sorry but no apps were found."]]
       when 1
-        apps.values.first.call(env) # When we have one
+        @reloader.apps.values.first.call(env) # When we have one
       else
         # 2 and up get special treatment
-        apps.each do |name, app|
+        @reloader.apps.each do |name, app|
           app.routes.each do |r|
             if (path_matches?(env['PATH_INFO'], r))
               return app.call(env)
@@ -270,7 +250,7 @@ module Camping
         end
 
         # Just return the first app if we didn't find a match.
-        return apps.values.first.call(env)
+        @reloader.apps.values.first.call(env)
       end
     end
 
