@@ -1,3 +1,6 @@
+require 'rack/session'
+class InsecureSecretError < Exception #:nodoc: all
+end
 module Camping
   # == Getting Started
   #
@@ -27,8 +30,9 @@ module Camping
   module Session
     def self.included(app)
       key    = "#{app}.state".downcase
-      secret = app.options[:secret] || [__FILE__, File.mtime(__FILE__)].join(":")
-      app.use Rack::Session::Cookie, :key => key, :secret => secret
+      secret = app.options[:secret] || ['camping-secret',__FILE__, File.mtime('Rakefile')].join(":")*2
+      raise InsecureSecretError, "Your Session Secret is too short. Minimum length is 64." if secret.length < 64
+      app.use Rack::Session::Cookie, :key => key, :secrets => secret
     end
   end
 end
