@@ -9,7 +9,7 @@ module Markup::Controllers
       render :index
     end
   end
-  
+
   class NoLayout
     def get
       render :index, :layout => false
@@ -47,14 +47,14 @@ module Markup::Views
   def index
     h1 "Welcome!"
   end
-  
+
   def layout
     self << '<!DOCTYPE html>'
     html do
       head do
         title "Web Page"
       end
-      
+
       body { yield }
     end
   end
@@ -67,11 +67,11 @@ class Markup::Test < TestCase
     assert_body %r{<h1>Welcome!</h1>}
     assert_body %r{<title>Web Page</title>}
   end
-  
+
   def test_no_layout
     get '/no/layout'
     assert_body %r{<h1>Welcome!</h1>}
-    
+
     assert_reverse do
       assert_body %r{<title>Web Page</title>}
     end
@@ -82,21 +82,6 @@ class Markup::Test < TestCase
     assert_body '<img src="/mount/hello.png">'
   end
 
-  def test_compat
-    warning = "xhtml_strict is no longer supported (or an active standard); using HTML5 instead\n"
-
-    assert_output '', warning * 3 do
-      get '/compat/xhtml_strict'
-      assert_body '<!DOCTYPE html><html><body><h1>Nice</h1></body></html>'
-
-      get '/compat/xhtml_transitional'
-      assert_body '<!DOCTYPE html><html><body><h1>Nice</h1></body></html>'
-
-      get '/compat/xhtml_frameset'
-      assert_body '<!DOCTYPE html><html><body><h1>Nice</h1></body></html>'
-    end
-  end
-
   def test_compat_helpers
     get '/compat/helpers'
     assert_body '/compat/helpers'
